@@ -506,7 +506,7 @@
         <translation type="obsolete">Öffne &quot;%1&quot; im Browser ...</translation>
     </message>
     <message>
-        <location filename="../src/mapwidget.cpp" line="425"/>
+        <location filename="../src/mapwidget.cpp" line="433"/>
         <source>Displayed cache data is %1 weeks old!</source>
         <translation>Angezeigte Cache-Daten sind %1 Wochen alt!</translation>
     </message>
@@ -1331,97 +1331,104 @@ Quazip-Teile Copyright 2005 durch Sergey A. Tachenov</translation>
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="176"/>
+        <location filename="../src/settingsdialog.cpp" line="202"/>
         <source>Settings</source>
         <translation>Einstellungen</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="88"/>
+        <location filename="../src/settingsdialog.cpp" line="103"/>
         <source>Type</source>
         <translation>Typ</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="82"/>
+        <location filename="../src/settingsdialog.cpp" line="97"/>
         <source>Hybrid Map</source>
         <translation>Hybridkarte</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="82"/>
+        <location filename="../src/settingsdialog.cpp" line="97"/>
         <source>Transit Map</source>
         <translation>ÖPNV-Karte</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="83"/>
+        <location filename="../src/settingsdialog.cpp" line="98"/>
         <source>Gray Street Map</source>
         <translation>Graue Straßenkarte</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="83"/>
+        <location filename="../src/settingsdialog.cpp" line="98"/>
         <source>Mobile Street Map</source>
         <translation>Mobile Straßenkarte</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="84"/>
+        <location filename="../src/settingsdialog.cpp" line="99"/>
         <source>Mobile Terrain Map</source>
         <translation>Mobile Geländekarte</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="84"/>
+        <location filename="../src/settingsdialog.cpp" line="99"/>
         <source>Mobile Hybrid Map</source>
         <translation>Mobile Hybridkarte</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="85"/>
+        <location filename="../src/settingsdialog.cpp" line="100"/>
         <source>Mobile Transit Map</source>
         <translation>Mobile ÖPNV-Karte</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="85"/>
+        <location filename="../src/settingsdialog.cpp" line="100"/>
         <source>Mobile Gray Street Map</source>
         <translation>Mobile graue Straßenkarte</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="107"/>
+        <location filename="../src/settingsdialog.cpp" line="122"/>
         <source>Service</source>
         <translation>Dienst</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="126"/>
+        <location filename="../src/settingsdialog.cpp" line="141"/>
         <source>Bigger icons</source>
         <translation>Große Icons</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="131"/>
+        <location filename="../src/settingsdialog.cpp" line="146"/>
         <source>Hide owned/found</source>
         <translation>Eigene/gefundene verstecken</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="182"/>
+        <location filename="../src/settingsdialog.cpp" line="87"/>
+        <location filename="../src/settingsdialog.cpp" line="209"/>
         <source>Map</source>
         <translation>Karte</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="183"/>
+        <location filename="../src/settingsdialog.cpp" line="151"/>
+        <source>Disable Screensaver</source>
+        <translation>Bildschirmschoner aus</translation>
+    </message>
+    <message>
+        <location filename="../src/settingsdialog.cpp" line="164"/>
+        <location filename="../src/settingsdialog.cpp" line="210"/>
         <source>Account</source>
         <translation>Zugang</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="80"/>
+        <location filename="../src/settingsdialog.cpp" line="95"/>
         <source>Street Map</source>
         <translation>Straßenkarte</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="80"/>
+        <location filename="../src/settingsdialog.cpp" line="95"/>
         <source>Satellite Map Day</source>
         <translation>Satellitenkarte Tag</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="81"/>
+        <location filename="../src/settingsdialog.cpp" line="96"/>
         <source>Satellite Map Night</source>
         <translation>Satellitenkarte Nacht</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="81"/>
+        <location filename="../src/settingsdialog.cpp" line="96"/>
         <source>Terrain Map</source>
         <translation>Geländekarte</translation>
     </message>
@@ -1434,7 +1441,7 @@ Quazip-Teile Copyright 2005 durch Sergey A. Tachenov</translation>
         <translation type="obsolete">Kartendienst</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="120"/>
+        <location filename="../src/settingsdialog.cpp" line="135"/>
         <source>A change of the map service takes effect after restart.</source>
         <translation>Ein Wechsel des Kartendienstes wird erst nach einem Neustart aktiv.</translation>
     </message>
@@ -1443,17 +1450,17 @@ Quazip-Teile Copyright 2005 durch Sergey A. Tachenov</translation>
         <translation type="obsolete">Hoch auflösender Bildschirm</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="149"/>
+        <location filename="../src/settingsdialog.cpp" line="175"/>
         <source>Geocaching.com account</source>
         <translation>Geocaching.com-Zugang</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="154"/>
+        <location filename="../src/settingsdialog.cpp" line="180"/>
         <source>Username</source>
         <translation>Benutzername</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="159"/>
+        <location filename="../src/settingsdialog.cpp" line="185"/>
         <source>Password</source>
         <translation>Passwort</translation>
     </message>
