@@ -15,10 +15,14 @@ class GcHtmlParser : public QObject {
   bool decode(const QString&, Cache &);
   QString error() const;
   void searchForItem(const QSgmlTag::QSgmlTaglist &, Cache &);
-  void searchForLogs(const QSgmlTag::QSgmlTaglist &, Cache &);
+  void searchForWaypoints(const QSgmlTag::QSgmlTaglist &, Cache &);
+  void parseWaypointTds(Waypoint &, QString &, const QString &, const QSgmlTag::QSgmlTaglist &);
+  void parseWaypointType(Waypoint::Type &, const QSgmlTag::QSgmlTaglist &);
   void searchForAttributes(const QSgmlTag::QSgmlTaglist &, Cache &);
+  void searchForLogs(const QSgmlTag::QSgmlTaglist &, Cache &);
   void parseLogDt(Log &, const QSgmlTag::QSgmlTaglist &);
   void parseLogDD(Log &, const QSgmlTag::QSgmlTaglist &);
+  bool isCheckbox(const QSgmlTag::QSgmlTaglist &);
   QString searchForHintEncrypted(const QSgmlTag::QSgmlTaglist &);
   QString searchForItemContentText(const QSgmlTag::QSgmlTaglist &);
   QString searchForItemHeader(const QSgmlTag::QSgmlTaglist &);
