@@ -26,6 +26,7 @@ QString Waypoint::iconFile() const {
     { Waypoint::Question,     "question" },
     { Waypoint::Trailhead,    "trailhead" },
     { Waypoint::Refpoint,     "refpoint" },
+    { Waypoint::Custom,       "custom" },
     { Waypoint::Unknown,      "<unknown>" }
   };
 
@@ -426,6 +427,11 @@ bool Tribool::value() const {
   return this->m_value;
 }
 
+bool Tribool::isSetAndTrue() const {
+  if(!this->m_set) return false;
+  return this->m_value;
+}
+
 bool Tribool::isSet() const {
   return this->m_set;
 }
