@@ -14,9 +14,15 @@ class CacheProvider  : public QObject {
   Q_OBJECT;
 
  public:
+  enum overviewFlags {
+    None        = 0x00,
+    NoFound     = 0x01,
+    NoOwned     = 0x02
+  };
+
   CacheProvider(QWidget *parent = 0);
   ~CacheProvider();
-  void requestOverview(const QGeoBoundingBox &);
+  void requestOverview(const QGeoBoundingBox &, int = None);
   void requestInfo(const QString &);
   void requestDetail(const QString &);
   void start(QWidget * = 0);
@@ -25,7 +31,7 @@ class CacheProvider  : public QObject {
   // functions redirected at current plugin
   QString name();
   bool busy();
-  void processRequestOverview(const QGeoBoundingBox &);
+  void processRequestOverview(const QGeoBoundingBox &, const int);
   void processRequestInfo(const QString &);
   void processRequestDetail(const QString &);
 
@@ -61,17 +67,19 @@ class CacheProvider  : public QObject {
   public: 
     enum RequestType { Overview, Info, Detail };
     RequestEntry(const RequestType &, const QString &);
-    RequestEntry(const RequestType &, const QGeoBoundingBox &);
+    RequestEntry(const RequestType &, const QGeoBoundingBox &, const int);
+    int flags();
     RequestType type();
     QGeoBoundingBox bbox();
     QString cache();
-    void set(const QGeoBoundingBox &);
+    void set(const QGeoBoundingBox &, const int);
     void set(const QString &);
 
   private:
     RequestType m_type;
     QGeoBoundingBox m_bbox;
     QString m_cache;
+    int m_flags;
   };
 
   class RequestQueue : public QQueue<RequestEntry *> {
@@ -81,7 +89,7 @@ class CacheProvider  : public QObject {
   public:
     RequestQueue(CacheProvider *);
     bool add(const RequestEntry::RequestType &, const QString &);
-    bool add(const RequestEntry::RequestType &, const QGeoBoundingBox &);
+    bool add(const RequestEntry::RequestType &, const QGeoBoundingBox &, const int);
     RequestEntry::RequestType type();
     void done();
     void next();
