@@ -35,15 +35,21 @@ class MainWindow : public CustomWindow {
   void selectCache(const QString &);
   void detailCache(const QString &);
   void setBusy(bool on);
+  void aboutBox(QWidget *, const QString &, const QString &);
 
  private slots:
   void about();
   void settingsdialog();
+  void helpButtonClicked();
   void showDetail(const Cache &);
 
+ signals:
+  void activated(bool);
+
  private:
   void createMenu();
-    
+  bool event(QEvent *);
+ 
   QGeoServiceProvider *m_serviceProvider;
   MapWidget *m_mapWidget;
   CacheProvider *m_cacheProvider;
