@@ -5,24 +5,25 @@
 #include "mapwidget.h"
 
 MapOverlay::MapOverlay(MapWidget *mapWidget) {
-  int step = 80;
-
   qDebug() << __FUNCTION__;
 
   // create a buttonmanager and fill with buttons
-  m_mapButtonManager = new MapButtonManager(mapWidget, 64);
-
-  MapButton *zoom_in = m_mapButtonManager->create("zoom_in", 16, 16);
+  m_mapButtonManager = new MapButtonManager(mapWidget);
+  
+  MapButton *zoom_in = m_mapButtonManager->create("zoom_in", 1, 1);
   QObject::connect(zoom_in, SIGNAL(clicked()), mapWidget, SLOT(zoomIn()));
-
-  MapButton *gps = m_mapButtonManager->create("gps", 16, 16+step, MapButton::Disabled);
+  
+  MapButton *gps = m_mapButtonManager->create("gps", 1, 2, MapButton::Disabled);
   QObject::connect(gps, SIGNAL(clicked()), mapWidget, SLOT(gpsFollow()));
-
-  MapButton *zoom_out = m_mapButtonManager->create("zoom_out", 16, 16+2*step);
+  
+  MapButton *zoom_out = m_mapButtonManager->create("zoom_out", 1, 3);
   QObject::connect(zoom_out, SIGNAL(clicked()), mapWidget, SLOT(zoomOut()));
-
-  MapButton *forward = m_mapButtonManager->create("forward", -16, 16, MapButton::Disabled);
+  
+  MapButton *forward = m_mapButtonManager->create("forward", -1, 1, MapButton::Disabled);
   QObject::connect(forward, SIGNAL(clicked()), mapWidget, SLOT(showDetails()));
+
+  MapButton *fullscreen = m_mapButtonManager->create("fs", -1, -1);
+  QObject::connect(fullscreen, SIGNAL(clicked()), mapWidget, SLOT(toggleFullscreen()));
 };
 
 MapOverlay::~MapOverlay() {
