@@ -25,7 +25,8 @@ void MapWidget::updateZoomButtons() {
 
 MapWidget::MapWidget(QGeoMappingManager *mgr) : 
   QGraphicsGeoMap(mgr), m_bubble(NULL), m_posIsValid(false), m_gpsMarker(NULL),
-  m_manager(mgr), m_wptDb(NULL), m_cacheListWasUpdated(false) {
+  m_manager(mgr), m_wptDb(NULL), m_cacheListWasUpdated(false),
+  m_screenSaver(NULL) {
   
   // try to get default from qsettings, otherwise start at berlin's zoo
   QSettings settings;
@@ -39,11 +40,18 @@ MapWidget::MapWidget(QGeoMappingManager *mgr) :
   m_gpsLocked = settings.value("GpsLocked", false).toBool();
   m_hiRez = settings.value("HiRez", false).toBool();
   m_hideOwn = settings.value("HideOwn", false).toBool();
+  m_disableScreensaver = settings.value("DisableScreenSaver", false).toBool();
   m_precisionAlpha = settings.value("PrecisionAlpha", 32).toInt();
   settings.endGroup();
   if(m_hiRez) m_iconLoader = new IconLoader(Config::MAP_WIDGET_ICON_SIZE_HIREZ);
   else        m_iconLoader = new IconLoader(Config::MAP_WIDGET_ICON_SIZE);
 
+  if(m_disableScreensaver) {
+    m_screenSaver = new QSystemScreenSaver();
+    if(!m_screenSaver->setScreenSaverInhibit())
+      qDebug() << __FUNCTION__ << "disabling the screensaver failed!";
+  }
+
   // create the control overlays
   this->m_mapOverlay = new MapOverlay(this);
   this->m_mapBanner = new MapBanner(this);
@@ -191,9 +199,7 @@ void MapWidget::showBubble(const Cache &cache) {
 
   hideBubble();
   m_bubble = new MapBubble(this, size().width() > size().height(), cache);
-  qDebug() << __FUNCTION__ << "A" << m_bubble << m_bubble->pixmap().size();
   addMapObject(m_bubble);
-  qDebug() << __FUNCTION__ << "B";
   this->m_mapOverlay->enableForwardButton(cache.url().isValid());
 }
 
@@ -381,12 +387,10 @@ void MapWidget::windowActivated(bool activated) {
   }
 }
 
-void MapWidget::updateCaches(const CacheList &cacheList) {
-  static bool tooOld = false;
-
+bool MapWidget::mapWindowIsActive() {
   // try to get access to parent window
   bool windowIsActive = false;
-
+  
   if(this->scene()) 
     if(this->scene()->views().size() == 1) 
       if(this->scene()->views()[0]) 
@@ -394,17 +398,19 @@ void MapWidget::updateCaches(const CacheList &cacheList) {
 	  windowIsActive = 
 	    this->scene()->views()[0]->window()->isActiveWindow();
 
-  if(!windowIsActive) {
+  return windowIsActive;
+}
+
+void MapWidget::updateCaches(const CacheList &cacheList) {
+  static bool tooOld = false;
+
+  if(!mapWindowIsActive()) {
     qDebug() << __FUNCTION__ << "delaying update";
     m_cacheListWasUpdated = true;
     m_cacheList2Update = cacheList;
     return;
   }
 
-  //  qDebug() << __FUNCTION__ << this->window();
-  //  if(this->window())
-  //    qDebug() << __FUNCTION__ << this->window()->hasFocus();
-
   // save cache if existing bubble
   Cache bubbleCache;
   Waypoint bubbleWaypoint;
@@ -503,6 +509,11 @@ void MapWidget::reload() {
 }
 
 void MapWidget::positionUpdated(const QCompassReading *reading) {
+  // don't do anything if map is not visible (especially to deal with#
+  // buggy symbian qt versions)
+  if(!mapWindowIsActive()) 
+    return;
+
   // we accept 90% calibration
   if(reading->calibrationLevel() > 0.9) {
     qreal newVal = reading->azimuth();
@@ -527,6 +538,11 @@ void MapWidget::positionUpdated(const QCompassReading *reading) {
 }
 
 void MapWidget::positionUpdated(const QGeoPositionInfo &pos) {
+  // don't do anything if map is not visible (especially to deal with#
+  // buggy symbian qt versions)
+  if(!mapWindowIsActive()) 
+    return;
+
   // change state of gps button to reflect gps availability
   if(m_posIsValid != pos.coordinate().isValid()) {
     this->m_mapOverlay->enableGpsButton(pos.coordinate().isValid());
@@ -616,6 +632,30 @@ void MapWidget::setHideOwn(bool hideOwn) {
   }
 }
 
+bool MapWidget::screenSaverDisabled() const {
+  return m_disableScreensaver;
+}
+
+void MapWidget::setScreenSaverDisabled(bool disableScreensaver) {
+  qDebug() << __FUNCTION__;
+
+  if(m_disableScreensaver != disableScreensaver) {
+    m_disableScreensaver = disableScreensaver;
+
+    // Who the f..k came up with this stupid screen saver API?
+    if(m_disableScreensaver) {
+      Q_ASSERT(!m_screenSaver);
+      m_screenSaver = new QSystemScreenSaver();
+      if(!m_screenSaver->setScreenSaverInhibit())
+	qDebug() << __FUNCTION__ << "disabling the screensaver failed!";
+    } else {
+      Q_ASSERT(m_screenSaver);
+      delete m_screenSaver;
+      m_screenSaver = NULL;
+    }
+  }
+}
+
 void MapWidget::reloadCustomWaypoints() {
   // waypointsDb has signalled that the waypoints have changed
   bool hadCustomWpts = (m_customWpts.size() != 0);
