@@ -1,6 +1,8 @@
 #ifndef MAP_WIDGET_H
 #define MAP_WIDGET_H
 
+#include <QSystemScreenSaver>
+
 #include <QGraphicsGeoMap>
 #include <QGeoMappingManager>
 #include <QGeoMapPixmapObject>
@@ -27,6 +29,7 @@ class MapWidget : public QGraphicsGeoMap {
  public:
   MapWidget(QGeoMappingManager*);
   ~MapWidget();
+  bool mapWindowIsActive();
   void updateCaches(const CacheList &);
   void updateZoomButtons();
   void hideBubble();
@@ -37,6 +40,8 @@ class MapWidget : public QGraphicsGeoMap {
   bool hideOwn() const;
   void setHideOwn(bool);
   void setWaypointDb(WaypointDb *);
+  bool screenSaverDisabled() const;
+  void setScreenSaverDisabled(bool);
 
  signals:
   void mapChanged(const int);
@@ -55,7 +60,8 @@ class MapWidget : public QGraphicsGeoMap {
   void showDetails();
   void setBusy(bool);
   void addBanner(const QString &);
-  
+  void windowActivated(bool);
+
  private slots:
   void reloadCustomWaypoints();
   void reloadTimerExpired();
@@ -64,7 +70,8 @@ class MapWidget : public QGraphicsGeoMap {
   void centerChangedEvent(const QGeoCoordinate &);
   void positionUpdated(const QGeoPositionInfo &);
   void positionUpdated(const QCompassReading *);
-  
+  void updateCaches();
+
  protected:
   void mousePressEvent(QGraphicsSceneMouseEvent *);
   void mouseReleaseEvent(QGraphicsSceneMouseEvent *);
@@ -104,6 +111,7 @@ class MapWidget : public QGraphicsGeoMap {
   bool m_gpsLocked;
   bool m_hiRez;
   bool m_hideOwn;
+  bool m_disableScreensaver;
   int m_precisionAlpha;
   QString m_selectedCache;
   QList<Waypoint> m_selectedWaypoints;
@@ -120,6 +128,10 @@ class MapWidget : public QGraphicsGeoMap {
 
   WaypointDb *m_wptDb;
   QList<Waypoint> m_customWpts;
+
+  bool m_cacheListWasUpdated;
+  CacheList m_cacheList2Update;
+  QSystemScreenSaver *m_screenSaver;
 };
 
 #endif // MAP_WIDGET_H
