@@ -1,5 +1,6 @@
 #include <QDebug>
 
+#include <QLocale>
 #include <QLabel>
 #include <QGroupBox>
 #include <math.h>
@@ -90,19 +91,25 @@ NavigationWindow::NavigationWindow(const Cache &cache,
 
   // right/bottom: the textual info
   QWidget *vbox = new QWidget(compass);
-  //  compass->setOther(vbox);
   QVBoxLayout *layout = new QVBoxLayout;
   layout->setContentsMargins(0,0,0,0);
   layout->setSpacing(0);
 
+#ifdef Q_OS_SYMBIAN
+  QWidget *groupBox = new QWidget();
+#else
   QGroupBox *groupBox = new QGroupBox();
+#endif
   QVBoxLayout *ivbox = new QVBoxLayout;
   m_latitude = new InfoWidget(tr("Latitude"));
   ivbox->addWidget(m_latitude);
   m_longitude = new InfoWidget(tr("Longitude"));
   ivbox->addWidget(m_longitude);
+  m_precision = new InfoWidget(tr("Precision"));
+  ivbox->addWidget(m_precision);
   groupBox->setLayout(ivbox);
   layout->addWidget(groupBox);
+
   layout->addStretch();
 
   m_coordinateTool = new CoordinateTool(m_cache, wptDb, this);
@@ -111,8 +118,7 @@ NavigationWindow::NavigationWindow(const Cache &cache,
   m_distance = new InfoWidget(tr("Distance"));
   m_coordinateTool->addWidget(m_distance);
 
-  layout->addStretch();
-
+  //  layout->addStretch();
 
   vbox->setLayout(layout);
   sbox->addWidget(vbox);
@@ -153,29 +159,34 @@ void NavigationWindow::setPosition(const QGeoPositionInfo &pos) {
   qreal dist = pos.coordinate().distanceTo(m_coo);
 
   m_distance->setInfo(distanceString(dist));
+  m_precision->setInfo(distanceString(
+      pos.attribute(QGeoPositionInfo::HorizontalAccuracy)));
   m_latitude->setInfo(CoordinateTool::latitudeString(pos.coordinate()));
   m_longitude->setInfo(CoordinateTool::longitudeString(pos.coordinate()));
 }
 
 QString NavigationWindow::distanceString(qreal dist) {
-  // current we only support metric units
-  
-#if 0  
-  /* 1 mil = 1760 yd = 5280 ft ... */
-  if(dist<0.018)      snprintf(str, len, "%.1f ft", dist*5280.0);
-  else if(dist<0.055) snprintf(str, len, "%.1f yd", dist*1760.0);
-  else if(dist<0.55)  snprintf(str, len, "%.0f yd", dist*1760.0);
-  else if(dist<10.0)  snprintf(str, len, "%.2f mi", dist);
-  else if(dist<100.0) snprintf(str, len, "%.1f mi", dist);
-  else                snprintf(str, len, "%.0f mi", dist);
-#endif
-
   QString str;
-  if(dist<10)          str = QString::number(dist, 'f', 2) + " m";
-  else if(dist<100)    str = QString::number(dist, 'f', 1) + " m";
-  else if(dist<1000)   str = QString::number(dist, 'f', 0) + " m";
-  else if(dist<100000) str = QString::number(dist/1000, 'f', 1) + " km";
-  else                 str = QString::number(dist/1000, 'f', 0) + " km";
+  QLocale locale;
+
+  if(locale.measurementSystem() == QLocale::ImperialSystem) {
+    /* 10 ft == 3.0480m / 1m == 3.28084 ft */ 
+    /* 10 yd == 9.144m / 1m == 1.0936133 yd */ 
+    /* 100 yd == 91.44m / 1m == 1.0936133 yd */ 
+    /* 1 mi = 1609.344m */ 
+    if(dist<3.048)         str = QString::number(dist * 3.28084, 'f', 2) + " ft";
+    else if(dist<9.144)    str = QString::number(dist * 1.0936133, 'f', 2) + " yd";
+    else if(dist<91.44)    str = QString::number(dist * 1.0936133, 'f', 1) + " yd";
+    else if(dist<16093.44) str = QString::number(dist / 1609.344, 'f', 2) + " mi";
+    else if(dist<160934.4) str = QString::number(dist / 1609.344, 'f', 1) + " mi";
+    else                   str = QString::number(dist / 1609.344, 'f', 0) + " mi";
+  } else {
+    if(dist<10)          str = QString::number(dist, 'f', 2) + " m";
+    else if(dist<100)    str = QString::number(dist, 'f', 1) + " m";
+    else if(dist<1000)   str = QString::number(dist, 'f', 0) + " m";
+    else if(dist<100000) str = QString::number(dist/1000, 'f', 1) + " km";
+    else                 str = QString::number(dist/1000, 'f', 0) + " km";
+  }
 
   return str;
 }
