@@ -31,7 +31,7 @@ class NavigationWindow : public CustomWindow {
  private:
   Cache m_cache;
   CoordinateTool *m_coordinateTool;
-  InfoWidget *m_latitude, *m_longitude, *m_distance;
+  InfoWidget *m_latitude, *m_longitude, *m_precision, *m_distance;
   QGeoCoordinate m_coo;
   QSystemScreenSaver m_screenSaver;
 };
